@@ -1,4 +1,4 @@
-/* $Id: anchor.c,v 1.30 2003/09/26 17:59:51 ukai Exp $ */
+/* $Id: anchor.c,v 1.33 2006/04/08 11:33:16 inu Exp $ */
 #include "fm.h"
 #include "myctype.h"
 #include "regex.h"
@@ -175,6 +175,8 @@ searchAnchor(AnchorList *al, char *str)
 	return NULL;
     for (i = 0; i < al->nanchor; i++) {
 	a = &al->anchors[i];
+	if (a->hseq < 0)
+	  continue;
 	if (!strcmp(a->url, str))
 	    return a;
     }
@@ -471,6 +473,7 @@ putHmarker(HmarkerList *ml, int line, int pos, int seq)
     }
     ml->marks[seq].line = line;
     ml->marks[seq].pos = pos;
+    ml->marks[seq].invalid = 0;
     return ml;
 }
 
@@ -778,7 +781,7 @@ link_list_panel(Buffer *buf)
 	al = buf->href;
 	for (i = 0; i < al->nanchor; i++) {
 	    a = &al->anchors[i];
-	    if (a->slave)
+	    if (a->hseq < 0 || a->slave)
 		continue;
 	    parseURL2(a->url, &pu, baseURL(buf));
 	    p = parsedURL2Str(&pu)->ptr;
