@@ -1,6 +1,7 @@
+/* $Id: hash.c,v 1.5 2003/04/07 16:27:10 ukai Exp $ */
 #include <string.h>
 #include "hash.h"
-#include "gc.h"
+#include <gc.h>
 
 static unsigned int
 hashfunc(char *s)
@@ -21,6 +22,9 @@ hashfunc(char *s)
 
 #define keycomp(x,y) !strcmp(x,y)
 
+/* *INDENT-OFF* */
 defhashfunc(char *, int, si)
 defhashfunc(char *, char *, ss)
-defhashfunc(char *, void *, hist)
+defhashfunc(char *, void *, sv)
+defhashfunc_i(int, void *, iv)
+/* *INDENT-ON* */
