@@ -1,7 +1,9 @@
-/* $Id: indep.c,v 1.35 2004/04/09 17:18:49 ukai Exp $ */
+/* $Id: indep.c,v 1.38 2007/05/23 15:06:05 inu Exp $ */
 #include "fm.h"
 #include <stdio.h>
+#ifndef __MINGW32_VERSION
 #include <pwd.h>
+#endif /* __MINGW32_VERSION */
 #include <sys/param.h>
 #include <sys/types.h>
 #include <stdlib.h>
@@ -225,6 +227,7 @@ expandPath(char *name)
     p = name;
     if (*p == '~') {
 	p++;
+#ifndef __MINGW32_VERSION
 	if (IS_ALPHA(*p)) {
 	    char *q = strchr(p, '/');
 	    if (q) {		/* ~user/dir... */
@@ -238,8 +241,9 @@ expandPath(char *name)
 	    if (!passent)
 		goto rest;
 	    extpath = Strnew_charp(passent->pw_dir);
-	}
-	else if (*p == '/' || *p == '\0') {	/* ~/dir... or ~ */
+	} else
+#endif /* __MINGW32_VERSION */
+	  if (*p == '/' || *p == '\0') {	/* ~/dir... or ~ */
 	    extpath = Strnew_charp(getenv("HOME"));
 	}
 	else
