@@ -1,4 +1,4 @@
-/* $Id: mailcap.c,v 1.10 2002/01/05 16:13:27 ukai Exp $ */
+/* $Id: mailcap.c,v 1.13 2006/08/07 03:10:26 ukai Exp $ */
 #include "fm.h"
 #include "myctype.h"
 #include <stdio.h>
@@ -21,7 +21,7 @@ mailcapMatch(struct mailcap *mcap, char *type)
     char *cap = mcap->type, *p;
     int level;
     for (p = cap; *p != '/'; p++) {
-	if (tolower(*p) != tolower(*type))
+	if (TOLOWER(*p) != TOLOWER(*type))
 	    return 0;
 	type++;
     }
@@ -36,7 +36,7 @@ mailcapMatch(struct mailcap *mcap, char *type)
     if (*p == '*')
 	return 10 + level;
     while (*p) {
-	if (tolower(*p) != tolower(*type))
+	if (TOLOWER(*p) != TOLOWER(*type))
 	    return 0;
 	p++;
 	type++;
@@ -187,7 +187,7 @@ loadMailcap(char *filename)
     Str tmp;
     struct mailcap *mcap;
 
-    f = fopen(expandName(filename), "r");
+    f = fopen(expandPath(filename), "r");
     if (f == NULL)
 	return NULL;
     i = 0;
@@ -252,7 +252,7 @@ acceptableMimeTypes()
     /* generate acceptable media types */
     l = newTextList();
     mhash = newHash_si(16);	/* XXX */
-    pushText(l, "text");
+    /* pushText(l, "text"); */
     putHash_si(mhash, "text", 1);
     pushText(l, "image");
     putHash_si(mhash, "image", 1);
@@ -272,11 +272,10 @@ acceptableMimeTypes()
 	    }
 	}
     }
+    types = Strnew();
+    Strcat_charp(types, "text/html, text/*;q=0.5");
     while ((p = popText(l)) != NULL) {
-	if (types == NULL)
-	    types = Strnew();
-	else
-	    Strcat_charp(types, ", ");
+	Strcat_charp(types, ", ");
 	Strcat_charp(types, p);
 	Strcat_charp(types, "/*");
     }
