@@ -1,3 +1,4 @@
+/* $Id: parsetag.c,v 1.4 2001/11/20 17:49:23 ukai Exp $ */
 #include "myctype.h"
 #include "indep.h"
 #include "Str.h"
@@ -38,7 +39,7 @@ cgistr2tagarg(char *cgistr)
 	tag = Strnew();
 	while (*cgistr && *cgistr != '=' && *cgistr != '&')
 	    Strcat_char(tag, *cgistr++);
-	t->arg = form_unquote(tag)->ptr;
+	t->arg = Str_form_unquote(tag)->ptr;
 	t->value = NULL;
 	if (*cgistr == '\0')
 	    return t;
@@ -47,7 +48,7 @@ cgistr2tagarg(char *cgistr)
 	    value = Strnew();
 	    while (*cgistr && *cgistr != '&')
 		Strcat_char(value, *cgistr++);
-	    t->value = form_unquote(value)->ptr;
+	    t->value = Str_form_unquote(value)->ptr;
 	}
 	else if (*cgistr == '&')
 	    cgistr++;
