@@ -1,4 +1,4 @@
-/* $Id: parsetagx.c,v 1.10 2002/10/16 18:11:15 ukai Exp $ */
+/* $Id: parsetagx.c,v 1.18 2006/06/07 03:52:03 inu Exp $ */
 #include "fm.h"
 #include "myctype.h"
 #include "indep.h"
@@ -45,7 +45,7 @@ toNumber(char *oval, int *num)
     char *ep;
     int x;
 
-    x = strtol(oval, &ep, 0);
+    x = strtol(oval, &ep, 10);
 
     if (ep > oval) {
 	*num = x;
@@ -128,9 +128,13 @@ parse_tag(char **s, int internal)
     }
     while (*q && !IS_SPACE(*q) && !(tagname[0] != '/' && *q == '/') &&
 	   *q != '>' && p - tagname < MAX_TAG_LEN - 1) {
-	*(p++) = tolower(*(q++));
+	*(p++) = TOLOWER(*q);
+	q++;
     }
     *p = '\0';
+    while (*q && !IS_SPACE(*q) && !(tagname[0] != '/' && *q == '/') &&
+	   *q != '>')
+	q++;
 
     tag_id = getHash_si(&tagtable, tagname, HTML_UNKNOWN);
 
@@ -155,31 +159,29 @@ parse_tag(char **s, int internal)
     /* Parse tag arguments */
     SKIP_BLANKS(q);
     while (1) {
-	Str value = NULL;
+       Str value = NULL, value_tmp = NULL;
 	if (*q == '>' || *q == '\0')
 	    goto done_parse_tag;
 	p = attrname;
 	while (*q && *q != '=' && !IS_SPACE(*q) &&
 	       *q != '>' && p - attrname < MAX_TAG_LEN - 1) {
-	    *(p++) = tolower(*(q++));
-	}
-	if (q == p) {
+	    *(p++) = TOLOWER(*q);
 	    q++;
-	    continue;
 	}
 	*p = '\0';
+	while (*q && *q != '=' && !IS_SPACE(*q) && *q != '>')
+	    q++;
 	SKIP_BLANKS(q);
 	if (*q == '=') {
 	    /* get value */
-	    value = Strnew();
+	    value_tmp = Strnew();
 	    q++;
 	    SKIP_BLANKS(q);
 	    if (*q == '"') {
 		q++;
 		while (*q && *q != '"') {
-		    if (*q != '\n')
-			Strcat_char(value, *q);
-		    if (!tag->need_reconstruct && html_quote_char(*q))
+		    Strcat_char(value_tmp, *q);
+		    if (!tag->need_reconstruct && is_html_quote(*q))
 			tag->need_reconstruct = TRUE;
 		    q++;
 		}
@@ -189,9 +191,8 @@ parse_tag(char **s, int internal)
 	    else if (*q == '\'') {
 		q++;
 		while (*q && *q != '\'') {
-		    if (*q != '\n')
-			Strcat_char(value, *q);
-		    if (!tag->need_reconstruct && html_quote_char(*q))
+		    Strcat_char(value_tmp, *q);
+		    if (!tag->need_reconstruct && is_html_quote(*q))
 			tag->need_reconstruct = TRUE;
 		    q++;
 		}
@@ -199,8 +200,12 @@ parse_tag(char **s, int internal)
 		    q++;
 	    }
 	    else if (*q) {
-		while (*q && !IS_SPACE(*q) && *q != '>')
-		    Strcat_char(value, *q++);
+		while (*q && !IS_SPACE(*q) && *q != '>') {
+                   Strcat_char(value_tmp, *q);
+		    if (!tag->need_reconstruct && is_html_quote(*q))
+			tag->need_reconstruct = TRUE;
+		    q++;
+		}
 	    }
 	}
 	for (i = 0; i < nattr; i++) {
@@ -211,6 +216,29 @@ parse_tag(char **s, int internal)
 		break;
 	    }
 	}
+
+       if (value_tmp) {
+         int j, hidden=FALSE;
+         for (j=0; j<i; j++) {
+           if (tag->attrid[j] == ATTR_TYPE &&
+               strcmp("hidden",tag->value[j]) == 0) {
+             hidden=TRUE;
+             break;
+           }
+         }
+         if ((tag_id == HTML_INPUT || tag_id == HTML_INPUT_ALT) &&
+             attr_id == ATTR_VALUE && hidden) {
+           value = value_tmp;
+         } else {
+           char *x;
+           value = Strnew();
+           for (x = value_tmp->ptr; *x; x++) {
+             if (*x != '\n')
+               Strcat_char(value, *x);
+           }
+         }
+       }
+
 	if (i != nattr) {
 	    if (!internal &&
 		((AttrMAP[attr_id].flag & AFLG_INT) ||
@@ -225,6 +253,9 @@ parse_tag(char **s, int internal)
 	    else
 		tag->value[i] = NULL;
 	}
+	else {
+	    tag->need_reconstruct = TRUE;
+	}
     }
 
   skip_parse_tagarg:
