@@ -1,8 +1,8 @@
-/* $Id: textlist.c,v 1.5 2002/09/24 16:35:02 ukai Exp $ */
+/* $Id: textlist.c,v 1.6 2003/04/07 16:27:11 ukai Exp $ */
 #include "textlist.h"
 #include "indep.h"
 #include "Str.h"
-#include "gc.h"
+#include <gc.h>
 
 /* General doubly linked list */
 
